@@ -1,20 +1,19 @@
-from datasets import load_dataset
-import pandas as pd
-import spacy
-from negspacy.negation import Negex
-from negspacy.termsets import termset
-from spacy import displacy
+# Copyright (c) Microsoft Corporation
+# Licensed under the MIT License.
 import gender_guesser.detector as gender
 import pkg_resources
+from negspacy.negation import Negex  # noqa: F401
 
+from raiutils.dataset import fetch_dataset
+
+POSITIVE_NEGATIVE_FILE = 'positive-negative.csv'
 
 resource_package = __name__
-positive_negative_words_path = '/'.join(('data', 'positive-negative.csv'))
+nlp_url = 'https://publictestdatasets.blob.core.windows.net/nlp/'
+fetch_dataset(nlp_url + POSITIVE_NEGATIVE_FILE, POSITIVE_NEGATIVE_FILE)
 male_words_path = '/'.join(('data', 'male-words.txt'))
 female_words_path = '/'.join(('data', 'female-words.txt'))
 neutral_words_path = '/'.join(('data', 'neutral-words.txt'))
-positive_negative_words_data = pkg_resources.resource_string(
-    resource_package, positive_negative_words_path).decode("utf-8")
 male_words_data = pkg_resources.resource_string(
     resource_package, male_words_path).decode("utf-8")
 female_words_data = pkg_resources.resource_string(
@@ -22,11 +21,10 @@ female_words_data = pkg_resources.resource_string(
 neutral_words_data = pkg_resources.resource_string(
     resource_package, neutral_words_path).decode("utf-8")
 
-# positive_negative_file = open("data/positive-negative.csv", "r")
-positive_negative_raw = positive_negative_words_data
-# positive_negative_file.close()
-positive_negative_lines = positive_negative_raw.split("\n")
+with open(POSITIVE_NEGATIVE_FILE, 'r', encoding='utf8') as pnf:
+    positive_negative_raw = pnf.read()
 
+positive_negative_lines = positive_negative_raw.split("\n")
 
 positive_words = set()
 negative_words = set()
@@ -39,13 +37,21 @@ for line in positive_negative_lines[2:]:
         positive_words.add(words[2])
 
 male_words_raw = male_words_data
-male_words = set(filter(lambda w: len(w) > 0, map(lambda w: w.strip(), male_words_raw.split("\n"))))
+male_words = set(
+    filter(
+        lambda w: len(w) > 0,
+        map(lambda w: w.strip(), male_words_raw.split("\n"))))
 
 female_words_raw = female_words_data
-female_words = set(filter(lambda w: len(w) > 0, map(lambda w: w.strip(), female_words_raw.split("\n"))))
+female_words = set(
+    filter(
+        lambda w: len(w) > 0,
+        map(lambda w: w.strip(), female_words_raw.split("\n"))))
 
 neutral_words_raw = neutral_words_data
-neutral_words = set(filter(lambda w: len(w) > 0, map(lambda w: w.strip(), neutral_words_raw.split("\n"))))
+neutral_words = set(filter(
+    lambda w: len(w) > 0,
+    map(lambda w: w.strip(), neutral_words_raw.split("\n"))))
 
 
 def positive_negative_word_count(nlp_doc):
@@ -57,23 +63,37 @@ def positive_negative_word_count(nlp_doc):
         elif token.lemma_ in negative_words or token.text in negative_words:
             negative_count += 1
 
-    return {"positive_word_count": positive_count, "negative_word_count": negative_count}
+    return {
+        "positive_word_count": positive_count,
+        "negative_word_count": negative_count}
 
 
 def get_named_persons(nlp_doc):
-    return list(map(lambda tok: tok.text, filter(lambda tok: tok.label_ == "PERSON", nlp_doc.ents)))
+    return list(map(
+        lambda tok: tok.text,
+        filter(lambda tok: tok.label_ == "PERSON", nlp_doc.ents)))
 
 
 def get_named_locations(nlp_doc):
-    return list(map(lambda tok: tok.text, filter(lambda tok: tok.label_ in ["LOC", "FAC"], nlp_doc.ents)))
+    return list(map(
+        lambda tok: tok.text,
+        filter(lambda tok: tok.label_ in ["LOC", "FAC"], nlp_doc.ents)))
 
 
 def get_dates(nlp_doc):
-    return list(map(lambda tok: tok.text, filter(lambda tok: tok.label_ == "DATE", nlp_doc.ents)))
+    return list(map(
+        lambda tok: tok.text,
+        filter(lambda tok: tok.label_ == "DATE", nlp_doc.ents)))
 
 
 def get_non_date_numerics(nlp_doc):
-    return list(map(lambda tok: tok.text, filter(lambda tok: tok.label_ in ["TIME", "PERCENT", "MONEY", "QUANTITY", "ORDINAL", "CARDINAL"], nlp_doc.ents)))
+    return list(map(
+        lambda tok: tok.text,
+        filter(
+            lambda tok: tok.label_ in [
+                "TIME", "PERCENT", "MONEY",
+                "QUANTITY", "ORDINAL", "CARDINAL"],
+            nlp_doc.ents)))
 
 
 def get_all_named_entities(nlp_doc):
@@ -154,13 +174,18 @@ def get_male_female_words_count(nlp_doc):
         elif gender_detector.get_gender(name) == ["andy", "unknown"]:
             neutral_count += 1
 
-    return {"male_count": male_count, "female_count": female_count, "neutral_count": neutral_count}
+    return {
+        "male_count": male_count,
+        "female_count": female_count,
+        "neutral_count": neutral_count}
 
 
 def detect_negation_words_and_entities(nlp_doc):
     negation_tokens = list(filter(lambda tok: tok.dep_ == "neg", nlp_doc))
     negated_entities = list(filter(lambda tok: tok._.negex, nlp_doc.ents))
-    return {"negation_words": len(negation_tokens), "negated_entities": len(negated_entities)}
+    return {
+        "negation_words": len(negation_tokens),
+        "negated_entities": len(negated_entities)}
 
 
 def dependency_parse_tree_depth(doc):
